const VIRTUAL_MODULE_ID = "astro:dev-overlay";
const resolvedVirtualModuleId = "\0" + VIRTUAL_MODULE_ID;
function astroDevOverlay({ settings }) {
  return {
    name: "astro:dev-overlay",
    resolveId(id) {
      if (id === VIRTUAL_MODULE_ID) {
        return resolvedVirtualModuleId;
      }
    },
    async load(id) {
      if (id === resolvedVirtualModuleId) {
        const resolvedPlugins = await Promise.all(
          settings.devOverlayPlugins.map((plugin) => resolvePlugin.call(this, plugin))
        );
        return `
					export const loadDevOverlayPlugins = async () => {
						return [${resolvedPlugins.map((plugin) => `(await import('${plugin}')).default`).join(",")}];
					};
				`;
      }
    }
  };
}
async function resolvePlugin(plugin) {
  const resolvedId = await this.resolve(plugin).then((res) => res?.id).catch(() => void 0);
  if (!resolvedId)
    return plugin;
  return resolvedId;
}
export {
  astroDevOverlay as default
};
